@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.073'; # must be numeric, i.e. not 1.07.1
+our $VERSION = '1.075'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -50,6 +50,22 @@ use constant MESSAGES_COMMENTREPLIES => 'comments';
 use constant MESSAGES_POSTREPLIES    => 'selfreply';
 use constant MESSAGES_MENTIONS	     => 'mentions';
 
+use constant SUBREDDITS_HOME         => '';
+use constant SUBREDDITS_MINE         => 'subscriber';
+use constant SUBREDDITS_POPULAR      => 'popular';
+use constant SUBREDDITS_NEW          => 'new';
+use constant SUBREDDITS_CONTRIB      => 'contributor';
+use constant SUBREDDITS_MOD          => 'moderator';
+
+use constant USER_OVERVIEW           => 'overview';
+use constant USER_COMMENTS           => 'comments';
+use constant USER_SUBMITTED          => 'submitted';
+use constant USER_GILDED             => 'gilded';
+use constant USER_UPVOTED            => 'upvoted';
+use constant USER_DOWNVOTED          => 'downvoted';
+use constant USER_HIDDEN             => 'hidden';
+use constant USER_SAVED              => 'saved';
+
 use constant API_ME                  => 0;
 use constant API_INFO                => 1;
 use constant API_SEARCH              => 2;
@@ -72,13 +88,7 @@ use constant API_MESSAGES	     => 18;
 use constant API_MARK_READ	     => 19;
 use constant API_MARKALL	     => 20;
 use constant API_MY_SUBREDDITS       => 21;
-
-use constant SUBREDDITS_HOME         => '';
-use constant SUBREDDITS_MINE         => 'subscriber';
-use constant SUBREDDITS_POPULAR      => 'popular';
-use constant SUBREDDITS_NEW          => 'new';
-use constant SUBREDDITS_CONTRIB      => 'contributor';
-use constant SUBREDDITS_MOD          => 'moderator';
+use constant API_USER                => 22;
 
 #===============================================================================
 # Parameters
@@ -114,6 +124,7 @@ $API[API_COMMENTS_FRONT] = ['GET',  '/comments'             ];
 $API[API_MESSAGES      ] = ['GET',  '/message/%s'           ];
 $API[API_MARK_READ     ] = ['POST', '/api/read_message'     ];
 $API[API_MARKALL       ] = ['POST', '/api/read_all_messages'];
+$API[API_USER          ] = ['GET',  '/user/%s/%s'           ];
 #===============================================================================
 # Package routines
 #===============================================================================
@@ -496,7 +507,6 @@ sub fetch_links {
     my ($self, %param) = @_;
     my $subreddit = $param{subreddit} || '';
     my $view      = $param{view}      || VIEW_DEFAULT;
-    #DEBUG('Fetch %d link(s): %s/%s?before=%s&after=%s', $limit, $subreddit, $view, ($before || '-'), ($after || '-'));
 
     	my $query  = {};
         $query->{before} = $param{before} if $param{before};
@@ -578,6 +588,40 @@ sub get_subreddit_comments {
     	];
 }
 
+# Get information about a user
+sub get_user {
+    	my ($self, %param) = @_;
+	my $view	= $param{view} || 'overview';
+	my $user	= $param{user} || croak "expected 'user'";
+
+    	my $query  = {};
+        $query->{before} = $param{before} if $param{before};
+        $query->{after}  = $param{after}  if $param{after};
+	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
+	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
+
+    	my $args = [$user, $view];
+
+	my $result = $self->api_json_request(
+		api      => API_USER,
+		args     => $args,
+		data     => $query,
+	);
+
+	# data property of $result->{data}{chilren}
+	# so $result->{data}{children}[0]->{data}
+
+	return [
+		map {
+
+		$_->{kind} eq "t1" ? 
+			Reddit::Client::Comment->new($self, $_->{data}) :
+			Reddit::Client::Link->new($self, $_->{data})
+		} 
+
+		@{$result->{data}{children}} 
+	];
+}
 #===============================================================================
 # Deleting stories or comments
 #===============================================================================
